# -*- coding: utf-8 -*-
STRUTTURA = [
    {
        'id': 'amministrazione-trasparente',
        'title': 'Amministrazione Trasparente',
        'type': 'Document',
        'children': [
            {
                'id': ' Disposizioni generali',
                'title': 'Disposizioni generali',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Piano triennale per la prevenzione della corruzione e della trasparenza',
                        'title': 'Piano triennale per la prevenzione della corruzione e della trasparenza',
                        'type': 'Document',
                    },
                    {
                        'id': 'Atti generali',
                        'title': 'Atti generali',
                        'type': 'Document',
                    },
                    {
                        'id': 'Oneri informativi per cittadini e imprese',
                        'title': 'Oneri informativi per cittadini e imprese',
                        'type': 'Document',
                    },
                    {
                        'id': 'Burocrazia zero',
                        'title': 'Burocrazia zero',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Organizzazione',
                'title': 'Organizzazione',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Titolari di incarichi politici, di amministrazione, di direzione o di governo',
                        'title': 'Titolari di incarichi politici, di amministrazione, di direzione o di governo',
                        'type': 'Document',
                    },
                    {
                        'id': 'Sanzioni per mancata comunicazione dei dati ',
                        'title': 'Sanzioni per mancata comunicazione dei dati',
                        'type': 'Document',
                    },
                    {
                        'id': 'Rendiconti gruppi consiliari regionali/provinciali',
                        'title': 'Rendiconti gruppi consiliari regionali/provinciali',
                        'type': 'Document',
                    },
                    {
                        'id': 'Articolazione degli uffici',
                        'title': 'Articolazione degli uffici',
                        'type': 'Document',
                    },
                    {
                        'id': 'Telefono e posta elettronica',
                        'title': 'Telefono e posta elettronica',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Consulenti e collaboratori',
                'title': 'Consulenti e collaboratori',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Titolari di incarichi di collaborazione o consulenza',
                        'title': 'Consulenti e collaboratori',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Personale',
                'title': 'Personale',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Titolari di incarichi dirigenziali amministrativi di vertice',
                        'title': 'Titolari di incarichi dirigenziali amministrativi di vertice',
                        'type': 'Document',
                    },
                    {
                        'id': 'Titolari di incarichi dirigenziali (dirigenti non generali)',
                        'title': 'Titolari di incarichi dirigenziali (dirigenti non generali)',
                        'type': 'Document',
                    },
                    {
                        'id': 'Dirigenti cessati',
                        'title': 'Dirigenti cessati',
                        'type': 'Document',
                    },
                    {
                        'id': 'Sanzioni per mancata comunicazione dei dati',
                        'title': 'Sanzioni per mancata comunicazione dei dati',
                        'type': 'Document',
                    },
                    {
                        'id': 'Posizioni organizzative',
                        'title': 'Posizioni organizzative',
                        'type': 'Document',
                    },
                    {
                        'id': 'Dotazione organica',
                        'title': 'Dotazione organica',
                        'type': 'Document',
                    },
                    {
                        'id': 'Personale non a tempo indeterminato',
                        'title': 'Personale non a tempo indeterminato',
                        'type': 'Document',
                    },
                    {
                        'id': 'Tassi di assenza',
                        'title': 'Tassi di assenza',
                        'type': 'Document',
                    },
                    {
                        'id': 'Incarichi conferiti e autorizzati ai dipendenti (dirigenti e non dirigenti)',
                        'title': 'Incarichi conferiti e autorizzati ai dipendenti (dirigenti e non dirigenti)',
                        'type': 'Document',
                    },
                    {
                        'id': 'Contrattazione collettiva',
                        'title': 'Contrattazione collettiva',
                        'type': 'Document',
                    },
                    {
                        'id': 'Contrattazione integrativa',
                        'title': 'Contrattazione integrativa',
                        'type': 'Document',
                    },
                    {
                        'id': 'OIV',
                        'title': 'OIV',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Bandi di concorso',
                'title': 'Bandi di concorso',
                'type': 'Document',
            },
            {
                'id': 'Performance',
                'title': 'Performance',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Sistema di misurazione e valutazione della Performance',
                        'title': 'Sistema di misurazione e valutazione della Performance',
                        'type': 'Document',
                    },
                    {
                        'id': 'Piano della Performance',
                        'title': 'Piano della Performance',
                        'type': 'Document',
                    },
                    {
                        'id': 'Relazione sulla Performance',
                        'title': 'Relazione sulla Performance',
                        'type': 'Document',
                    },
                    {
                        'id': 'Ammontare complessivo dei premi',
                        'title': 'Ammontare complessivo dei premi',
                        'type': 'Document',
                    },
                    {
                        'id': 'Dati relativi ai premi',
                        'title': 'Dati relativi ai premi',
                        'type': 'Document',
                    },
                    {
                        'id': 'Benessere organizzativo',
                        'title': 'Benessere organizzativo',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Enti controllati',
                'title': 'Enti controllati',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Enti pubblici vigilati',
                        'title': 'Enti pubblici vigilati',
                        'type': 'Document',
                    },
                    {
                        'id': 'Società partecipate',
                        'title': 'Società partecipate',
                        'type': 'Document',
                    },
                    {
                        'id': 'Enti di diritto privato controllati',
                        'title': 'Enti di diritto privato controllati',
                        'type': 'Document',
                    },
                    {
                        'id': 'Rappresentazione grafica',
                        'title': 'Rappresentazione grafica',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Attività e procedimenti',
                'title': 'Attività e procedimenti',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Tipologie di procedimento',
                        'title': 'Tipologie di procedimento',
                        'type': 'Document',
                    },
                    {
                        'id': 'Monitoraggio tempi procedimentali',
                        'title': 'Monitoraggio tempi procedimentali',
                        'type': 'Document',
                    },
                    {
                        'id': 'Dichiarazioni sostitutive e acquisizione d\'ufficio dei dati',
                        'title': 'Dichiarazioni sostitutive e acquisizione d\'ufficio dei dati',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Provvedimenti',
                'title': 'Provvedimenti',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Provvedimenti organi indirizzo politico',
                        'title': 'Provvedimenti organi indirizzo politico',
                        'type': 'Document',
                    },
                    {
                        'id': 'Provvedimenti organi indirizzo politico',
                        'title': 'Provvedimenti organi indirizzo politico',
                        'type': 'Document',
                    },
                    {
                        'id': 'Provvedimenti dirigenti amministrativi',
                        'title': 'Provvedimenti dirigenti amministrativi',
                        'type': 'Document',
                    },
                    {
                        'id': 'Provvedimenti dirigenti amministrativi',
                        'title': 'Provvedimenti dirigenti amministrativi',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Controlli sulle imprese',
                'title': 'Controlli sulle imprese',
                'type': 'Document',
            },
            {
                'id': 'Bandi di gara e contratti',
                'title': 'Bandi di gara e contratti',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Informazioni sulle singole procedure in formato tabellare',
                        'title': 'Informazioni sulle singole procedure in formato tabellare',
                        'type': 'Document',
                    },
                    {
                        'id': 'Atti delle amministrazioni aggiudicatrici e degli enti aggiudicatori distintamente per ogni procedura',
                        'title': 'Atti delle amministrazioni aggiudicatrici e degli enti aggiudicatori distintamente per ogni procedura',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Sovvenzioni,contributi,sussidi,vantaggi economici',
                'title': 'Sovvenzioni, contributi, sussidi, vantaggi economici',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Criteri e modalità',
                        'title': 'Criteri e modalità',
                        'type': 'Document',
                    },
                    {
                        'id': 'Atti di concessione',
                        'title': 'Atti di concessione',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Bilanci',
                'title': 'Bilanci',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Bilancio preventivo e consuntivo',
                        'title': 'Bilancio preventivo e consuntivo',
                        'type': 'Document',
                    },
                    {
                        'id': 'Piano degli indicatori e risultati attesi di bilancio',
                        'title': 'Piano degli indicatori e risultati attesi di bilancio',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Beni immobili e gestione patrimonio',
                'title': 'Beni immobili e gestione patrimonio',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Patrimonio immobiliare',
                        'title': 'Patrimonio immobiliare',
                        'type': 'Document',
                    },
                    {
                        'id': 'Canoni di locazione o affitto',
                        'title': 'Canoni di locazione o affitto',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Controlli e rilievi sull\'amministrazione',
                'title': 'Controlli e rilievi sull\'amministrazione',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Organismi indipendenti di valutazione, nuclei di valutazione o altri organismi con funzioni analoghe',
                        'title': 'Organismi indipendenti di valutazione, nuclei di valutazione o altri organismi con funzioni analoghe',
                        'type': 'Document',
                    },
                    {
                        'id': 'Organi di revisione amministrativa e contabile',
                        'title': 'Organi di revisione amministrativa e contabile',
                        'type': 'Document',
                    },
                    {
                        'id': 'Corte dei conti',
                        'title': 'Corte dei conti',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Servizi erogati',
                'title': 'Servizi erogati',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Carta dei servizi e standard di qualità',
                        'title': 'Carta dei servizi e standard di qualità',
                        'type': 'Document',
                    },
                    {
                        'id': 'Class Action',
                        'title': 'Class Action',
                        'type': 'Document',
                    },
                    {
                        'id': 'Costi contabilizzati',
                        'title': 'Costi contabilizzati',
                        'type': 'Document',
                    },
                    {
                        'id': 'Liste di attesa',
                        'title': 'Liste di attesa',
                        'type': 'Document',
                    },
                    {
                        'id': 'Servizi in rete',
                        'title': 'Servizi in rete',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Pagamenti dell\'amministrazione',
                'title': 'Pagamenti dell\'amministrazione',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Dati sui pagamenti',
                        'title': 'Dati sui pagamenti',
                        'type': 'Document',
                    },
                    {
                        'id': 'Dati sui pagamenti del servizio sanitario nazionale',
                        'title': 'Dati sui pagamenti del servizio sanitario nazionale',
                        'type': 'Document',
                    },
                    {
                        'id': 'Indicatore di tempestività dei pagamenti',
                        'title': 'Indicatore di tempestività dei pagamenti',
                        'type': 'Document',
                    },
                    {
                        'id': 'IBAN e pagamenti informatici',
                        'title': 'IBAN e pagamenti informatici',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Opere pubbliche',
                'title': 'Opere pubbliche',
                'type': 'Document',
                'children': [
                    {
                        'id': 'Nuclei di valutazione e verifica degli investimenti pubblici',
                        'title': 'Nuclei di valutazione e verifica degli investimenti pubblici',
                        'type': 'Document',
                    },
                    {
                        'id': 'Atti di programmazione delle opere pubbliche',
                        'title': 'Atti di programmazione delle opere pubbliche',
                        'type': 'Document',
                    },
                    {
                        'id': 'Tempi costi e indicatori di realizzazione delle opere pubbliche',
                        'title': 'Tempi costi e indicatori di realizzazione delle opere pubbliche',
                        'type': 'Document',
                    },
                ],
            },
            {
                'id': 'Pianificazione e governo del territorio',
                'title': 'Pianificazione e governo del territorio',
                'type': 'Document',
            },
            {
                'id': 'Informazioni ambientali',
                'title': 'Informazioni ambientali',
                'type': 'Document',
            },
            {
                'id': 'Strutture sanitarie private accreditate',
                'title': 'Strutture sanitarie private accreditate',
                'type': 'Document',
            },
            {
                'id': 'Interventi straordinari e di emergenza',
                'title': 'Interventi straordinari e di emergenza',
                'type': 'Document',
            },
            {
                'id': 'Altri contenuti - Prevenzione della corruzione',
                'title': 'Prevenzione della corruzione',
                'type': 'Document',
            },
            {
                'id': 'Altri contenuti - Accesso Civico',
                'title': 'Accesso Civico',
                'type': 'Document',
            },
            {
                'id': 'Altri contenuti - Accessibilità e catalogo di dati, metadati e banche dati',
                'title': 'Accessibilità e catalogo di dati, metadati e banche dati',
                'type': 'Document',
            },
            {
                'id': 'Altri Contenuti',
                'title': 'Altri contenuti',
                'type': 'Document',
            },
        ],
    },
]
